diff --git a/addons/hr/data/hr_data.xml b/addons/hr/data/hr_data.xml
index cab45c06385..bb2cf4b5a08 100644
--- a/addons/hr/data/hr_data.xml
+++ b/addons/hr/data/hr_data.xml
@@ -21,12 +21,12 @@ Leave Management (keep track of employee leaves), Expense Management (manage emp
Sales
-
- Pieter Parker
+
+
-
+
diff --git a/addons/hr/data/hr_demo.xml b/addons/hr/data/hr_demo.xml
index 46edbcbb889..f1853e5b6c1 100644
--- a/addons/hr/data/hr_demo.xml
+++ b/addons/hr/data/hr_demo.xml
@@ -135,7 +135,8 @@ If you have development competencies, we can propose you specific traineeships
-
+
+ Pieter Parker
Building 1, Second Floor
+3281813700
@@ -143,6 +144,7 @@ If you have development competencies, we can propose you specific traineeships
+
@@ -233,7 +235,7 @@ If you have development competencies, we can propose you specific traineeships
Martin Lawrence
-
+
Building 1, Second Floor
@@ -245,7 +247,7 @@ If you have development competencies, we can propose you specific traineeships
Jimmy Kosikin
-
+
Building 1, Second Floor
@@ -257,7 +259,7 @@ If you have development competencies, we can propose you specific traineeships
Famke Jenssens
-
+
Building 1, Second Floor
@@ -269,7 +271,7 @@ If you have development competencies, we can propose you specific traineeships
Ashley Presley
-
+
Building 1, Second Floor
diff --git a/addons/hr_attendance/hr_attendance_demo.xml b/addons/hr_attendance/hr_attendance_demo.xml
index b848951203f..9f265113b83 100644
--- a/addons/hr_attendance/hr_attendance_demo.xml
+++ b/addons/hr_attendance/hr_attendance_demo.xml
@@ -5,121 +5,121 @@
sign_in
-
+
sign_out
-
+
sign_in
-
+
sign_out
-
+
sign_in
-
+
sign_out
-
+
sign_in
-
+
sign_out
-
+
sign_in
-
+
sign_out
-
+
sign_in
-
+
sign_out
-
+
sign_in
-
+
sign_out
-
+
sign_in
-
+
sign_out
-
+
sign_in
-
+
sign_out
-
+
sign_in
-
+
sign_out
-
+
diff --git a/addons/hr_attendance/test/hr_attendance_report.yml b/addons/hr_attendance/test/hr_attendance_report.yml
index 1a55ffcf496..048a95735cd 100644
--- a/addons/hr_attendance/test/hr_attendance_report.yml
+++ b/addons/hr_attendance/test/hr_attendance_report.yml
@@ -4,6 +4,6 @@
!python {model: hr.employee}: |
import time
from openerp.tools import test_reports
- ctx = {'model': 'hr.employee','active_ids': [ref('hr.employee_fp')]}
+ ctx = {'model': 'hr.employee','active_ids': [ref('hr.employee_root')]}
data_dict = {'init_date': time.strftime('%Y-01-01')}
test_reports.try_report_action(cr, uid, 'action_hr_attendance_error',wiz_data=data_dict, context=ctx, our_module='hr_attendance')
diff --git a/addons/hr_expense/data/hr_expense_demo.xml b/addons/hr_expense/data/hr_expense_demo.xml
index bea4c5b26db..1128b8ceffb 100644
--- a/addons/hr_expense/data/hr_expense_demo.xml
+++ b/addons/hr_expense/data/hr_expense_demo.xml
@@ -16,7 +16,7 @@
-
+
diff --git a/addons/hr_holidays/data/hr_holidays_demo.xml b/addons/hr_holidays/data/hr_holidays_demo.xml
index 6a1d201e274..555150a5d12 100644
--- a/addons/hr_holidays/data/hr_holidays_demo.xml
+++ b/addons/hr_holidays/data/hr_holidays_demo.xml
@@ -7,7 +7,7 @@
add
20
-
+
@@ -17,7 +17,7 @@
add
7
-
+
@@ -28,7 +28,7 @@
add
draft
7
-
+
@@ -41,7 +41,7 @@
remove
3
-
+
@@ -52,7 +52,7 @@
remove
draft
3
-
+
diff --git a/addons/l10n_in_hr_payroll/test/payment_advice.yml b/addons/l10n_in_hr_payroll/test/payment_advice.yml
index 173bbe6fb20..a37784c8e33 100644
--- a/addons/l10n_in_hr_payroll/test/payment_advice.yml
+++ b/addons/l10n_in_hr_payroll/test/payment_advice.yml
@@ -7,7 +7,7 @@
name: 'NEFT Advice'
bank_id: base.res_bank_1
line_ids:
- - employee_id: hr.employee_fp
+ - employee_id: hr.employee_root
name: '90125452552'
ifsc_code: 'abn45215145'
bysal: 25000.00
diff --git a/addons/website_hr/data/hr_employee_demo.xml b/addons/website_hr/data/hr_employee_demo.xml
index 3d4c50513b4..5546a47dfe4 100644
--- a/addons/website_hr/data/hr_employee_demo.xml
+++ b/addons/website_hr/data/hr_employee_demo.xml
@@ -6,7 +6,7 @@
Designer, UI Expert
-
+
Lean Management Expert
diff --git a/addons/hr_holidays/tests/test_holidays_flow.py b/addons/hr_holidays/tests/test_holidays_flow.py
index b89631d3db6..9d1bc610932 100644
--- a/addons/hr_holidays/tests/test_holidays_flow.py
+++ b/addons/hr_holidays/tests/test_holidays_flow.py
@@ -184,8 +184,8 @@ class TestHolidaysFlow(TestHrHolidaysBase):
with self.assertRaises(ValidationError):
hol2_manager_group.signal_workflow('confirm')
- employee_id = self.ref('hr.employee_fp')
- # cl can be of maximum 20 days for employee_fp
+ employee_id = self.ref('hr.employee_root')
+ # cl can be of maximum 20 days for employee_root
hol3_status = self.env.ref('hr_holidays.holiday_status_cl').with_context(employee_id=employee_id)
# I assign the dates in the holiday request for 1 day
hol3 = Holidays.create({
@@ -215,7 +215,7 @@ class TestHolidaysFlow(TestHrHolidaysBase):
# Print the HR Holidays(Summary Department) Report through the wizard
ctx = {
'model': 'hr.department',
- 'active_ids': [self.ref('hr.employee_fp'), self.ref('hr.employee_qdp'), self.ref('hr.employee_al')]
+ 'active_ids': [self.ref('hr.employee_root'), self.ref('hr.employee_qdp'), self.ref('hr.employee_al')]
}
data_dict = {
'date_from': datetime.today().strftime('%Y-%m-01'),
@@ -227,11 +227,11 @@ class TestHolidaysFlow(TestHrHolidaysBase):
# Print the HR Holidays(Summary Employee) Report through the wizard
ctx = {
'model': 'hr.employee',
- 'active_ids': [self.ref('hr.employee_fp'), self.ref('hr.employee_qdp'), self.ref('hr.employee_al')]
+ 'active_ids': [self.ref('hr.employee_root'), self.ref('hr.employee_qdp'), self.ref('hr.employee_al')]
}
data_dict = {
'date_from': datetime.today().strftime('%Y-%m-01'),
- 'emp': [(6, 0, [self.ref('hr.employee_fp'), self.ref('hr.employee_qdp'), self.ref('hr.employee_al')])],
+ 'emp': [(6, 0, [self.ref('hr.employee_root'), self.ref('hr.employee_qdp'), self.ref('hr.employee_al')])],
'holiday_type': 'Approved'
}
test_reports.try_report_action(self.env.cr, self.env.uid, 'action_hr_holidays_summary_employee', wiz_data=data_dict, context=ctx, our_module='hr_holidays')